aboutsummaryrefslogtreecommitdiffstats
path: root/include/gmock/gmock-actions.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/gmock/gmock-actions.h')
-rw-r--r--include/gmock/gmock-actions.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/gmock/gmock-actions.h b/include/gmock/gmock-actions.h
index 215af4f9..f88ac80d 100644
--- a/include/gmock/gmock-actions.h
+++ b/include/gmock/gmock-actions.h
@@ -494,11 +494,11 @@ class ReturnAction {
// single-argument constructor (e.g. Result is std::vector<int>) and R
// has a type conversion operator template. In that case, value_(value)
// won't compile as the compiler doesn't known which constructor of
// Result to call. implicit_cast forces the compiler to convert R to
// Result without considering explicit constructors, thus resolving the
// ambiguity. value_ is then initialized using its copy constructor.
explicit Impl(R value)
- : value_(::testing::internal::implicit_cast<Result>(value)) {}
+ : value_(::testing::internal::ImplicitCast_<Result>(value)) {}
virtual Result Perform(const ArgumentTuple&) { return value_; }
@@ -494,11 +494,11 @@ class ReturnAction {
// has a type conversion operator template. In that case, value_(value)
// won't compile as the compiler doesn't known which constructor of
- // Result to call. implicit_cast forces the compiler to convert R to
+ // Result to call. ImplicitCast_ forces the compiler to convert R to
// Result without considering explicit constructors, thus resolving the
// ambiguity. value_ is then initialized using its copy constructor.